@@ -1,7 +1,8 @@
 "getnodes" <-
 function(qrf,x){
   nodes <- matrix(nrow=nrow(x),ncol=qrf$ntree)
-  nodes <- randomForest:::predict.randomForest(qrf,newdata=x,predict.all=TRUE)$individual  
+  class(qrf)<-"randomForest"
+  nodes <- predict(qrf,newdata=x,predict.all=TRUE)$individual  
   return(nodes)
 }
 
